@@ -48,8 +48,9 @@ struct ts_sample {
 };
 
 struct ts_sample_mt {
-	/* most recent ABS_MT_* event codes.
-	 * see linux/input.h for descriptions */
+	/* ABS_MT_* event codes. linux/include/uapi/linux/input-event-codes.h
+	 * has the definitions.
+	 */
 	int		x;
 	int		y;
 	unsigned int	pressure;
@@ -73,10 +74,19 @@ struct ts_sample_mt {
 	short		pen_down;
 
 	/* valid is set to 1 if this sample
-	 * contains new data; set to 0 otherwise */
+	 * contains new data; set to 0 otherwise
+	 */
 	short		valid;
 };
 
+struct ts_lib_version_data {
+	const char	*package_version;
+	int		version_num;
+	unsigned int	features; /* bitmask, see below */
+};
+
+#define TSLIB_VERSION_MT	(1 << 0)	/* multitouch support */
+
 enum ts_param {
 	TS_SCREEN_RES = 0,		/* 2 integer args, x and y */
 	TS_SCREEN_ROT			/* 1 integer arg, 1 = rotate */
@@ -147,6 +157,11 @@ TSAPI int ts_read_mt(struct tsdev *, struct ts_sample_mt **, int slots, int nr);
  */
 TSAPI int ts_read_raw_mt(struct tsdev *, struct ts_sample_mt **, int slots, int nr);
 
+/*
+ * This function returns a pointer to a static copy of the version info struct.
+ */
+TSAPI struct ts_lib_version_data *ts_libversion(void);
+
 #ifdef __cplusplus
 }
 #endif /* __cplusplus */
